****************************************************************************

* || SCM GDPpc || *

****************************************************************************
clear all
*
set memory 100m
set more off
import excel Data_WDI_panel_version_LICsample_GDPpc.xlsx, firstrow
****************************************************************************
{
drop if CountryCode==""
rename CountryCode iso3
rename CountryName country
rename Time year

foreach x in GDPpercapitaPPPconstant20 {
replace `x'="" if `x'==".."
destring `x', replace
}
**
g gdppc2012= GDPpercapitaPPPconstant20 if year ==2012
bysort iso3: egen denominator= max(gdppc2012)

g gdppc_index= GDPpercapitaPPPconstant20/denominator*100 
label var gdppc_index "GDPpc PPP (constant 2017 int. USD) index=100 2012"
drop gdppc2012 denominator

rename GDPpercapitaPPPconstant20 GDPpc_ppp 
label var GDPpc_ppp "GDPpc PPP (constant 2017 international USD)"

**
keep if year>=1990 & year<=2017 
bysort iso3: egen c_gdp = count(gdppc_index) if gdppc_index!=.

bysort iso3: sum c_gdp
keep if c_gdp==28
drop if iso3=="AFG" | iso3=="SYR" | iso3=="YEM" // Countries in war at the time of the treatment
sort country year
egen id= group(iso3)
list country id if year==2012 // CAR = ccode 3
order id iso3 country year TimeCode GDPpc_ppp gdppc_index

// SCM CAR: year of interest ==> 2012
{
/*
Potential donnor pool : BFA, BDI, TCD, COD, ETH, GMB, GIN, GNB, MDG, MWI, MOZ, NER, RWA, SLE, SDN, TGO, UGA, ZMB
*/

xtset id year

*=> 1990-2017
synth GDPpc_ppp GDPpc_ppp(1990) GDPpc_ppp(1991) GDPpc_ppp(1992) GDPpc_ppp(1993)  GDPpc_ppp(1994)  GDPpc_ppp(1995)  GDPpc_ppp(1996)  GDPpc_ppp(1997) GDPpc_ppp(1998) GDPpc_ppp(1999)  GDPpc_ppp(2000) GDPpc_ppp(2001) GDPpc_ppp(2002) GDPpc_ppp(2003) GDPpc_ppp(2004) GDPpc_ppp(2005) GDPpc_ppp(2006) GDPpc_ppp(2007) GDPpc_ppp(2008) GDPpc_ppp(2009) GDPpc_ppp(2010) GDPpc_ppp(2011), trunit(3) trperiod(2012)  figure keep(SCM1_LIC_GDPpc.dta, replace) // 2012 last year before war

}

// PLACEBO TEST
{

preserve
drop if id==3 // CAR
global id  1 2 4 5 6 7 8 9 10 12 13 14 16 17 18 19 20
tempname resmat
tempname effect

foreach i of global id {
	synth GDPpc_ppp GDPpc_ppp(1990) GDPpc_ppp(1991) GDPpc_ppp(1992) GDPpc_ppp(1993)  GDPpc_ppp(1994)  GDPpc_ppp(1995)  GDPpc_ppp(1996)  GDPpc_ppp(1997) GDPpc_ppp(1998) GDPpc_ppp(1999)  GDPpc_ppp(2000) GDPpc_ppp(2001) GDPpc_ppp(2002) GDPpc_ppp(2003) GDPpc_ppp(2004) GDPpc_ppp(2005) GDPpc_ppp(2006) GDPpc_ppp(2007) GDPpc_ppp(2008) GDPpc_ppp(2009) GDPpc_ppp(2010) GDPpc_ppp(2011), trunit(`i') trperiod(2012) nested // nested option removed for (id=11) Mozambique and (id=15) Sudan
	matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
	matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
	local names `"`names' `"`i'"'"'
	
}

/*
*/
synth GDPpc_ppp GDPpc_ppp(1990) GDPpc_ppp(1991) GDPpc_ppp(1992) GDPpc_ppp(1993)  GDPpc_ppp(1994)  GDPpc_ppp(1995)  GDPpc_ppp(1996)  GDPpc_ppp(1997) GDPpc_ppp(1998) GDPpc_ppp(1999)  GDPpc_ppp(2000) GDPpc_ppp(2001) GDPpc_ppp(2002) GDPpc_ppp(2003) GDPpc_ppp(2004) GDPpc_ppp(2005) GDPpc_ppp(2006) GDPpc_ppp(2007) GDPpc_ppp(2008) GDPpc_ppp(2009) GDPpc_ppp(2010) GDPpc_ppp(2011), trunit(11) trperiod(2012) /*nested*/ // nested option removed for Mozambique [lead to error in computation]
matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
local names `"`names' `"`11'"'"'

synth GDPpc_ppp GDPpc_ppp(1990) GDPpc_ppp(1991) GDPpc_ppp(1992) GDPpc_ppp(1993)  GDPpc_ppp(1994)  GDPpc_ppp(1995)  GDPpc_ppp(1996)  GDPpc_ppp(1997) GDPpc_ppp(1998) GDPpc_ppp(1999)  GDPpc_ppp(2000) GDPpc_ppp(2001) GDPpc_ppp(2002) GDPpc_ppp(2003) GDPpc_ppp(2004) GDPpc_ppp(2005) GDPpc_ppp(2006) GDPpc_ppp(2007) GDPpc_ppp(2008) GDPpc_ppp(2009) GDPpc_ppp(2010) GDPpc_ppp(2011), trunit(15) trperiod(2012) /*nested*/ // nested option removed for Sudan [lead to error in computation]
matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
local names `"`names' `"`15'"'"'


restore

synth GDPpc_ppp GDPpc_ppp(1990) GDPpc_ppp(1991) GDPpc_ppp(1992) GDPpc_ppp(1993)  GDPpc_ppp(1994)  GDPpc_ppp(1995)  GDPpc_ppp(1996)  GDPpc_ppp(1997) GDPpc_ppp(1998) GDPpc_ppp(1999)  GDPpc_ppp(2000) GDPpc_ppp(2001) GDPpc_ppp(2002) GDPpc_ppp(2003) GDPpc_ppp(2004) GDPpc_ppp(2005) GDPpc_ppp(2006) GDPpc_ppp(2007) GDPpc_ppp(2008) GDPpc_ppp(2009) GDPpc_ppp(2010) GDPpc_ppp(2011), trunit(3) trperiod(2012) nested /*counit(1 2 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20)*/ 
	matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
	matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
	local names `"`names' `"`3'"'"' 
	
mat colnames `resmat' = "RMSPE"
mat rownames `resmat' = `names'
mat colnames `effect' = "Treatment Effect"
matlist `resmat', row("Treated Unit")
matlist `effect', row("Year")
svmat `resmat', names(rmspe)
svmat `effect', names(te)


**
g mspe = rmspe1*rmspe1
scalar threshold5 = 537.40234* 5
tab mspe if mspe>threshold5 // to exclude: te1 te3 te4 te6 te7 te8 te12 te14 te15 te16 te17 te18 te19
**

keep year te*
drop if te1==. // ``clean'' the database
rename te20 car // CAR effect 

*=> standardize to 0 for year 2012 (reference)
rename car te20
reshape long te, i(year) j(country)
sort country year
by country: gen v = te[23] // 2012 is the 23rd year
replace te = te - v
drop v
reshape wide te, i(year) j(country)
rename te20 car  // CAR effect 

// CAR ALONE

#delimit ;
twoway
	(tsline car, lcolor(black) lwidth(medthick)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap GDPpc PPP (constant 2017 int. USD)")
	xtitle("Year")
	subtitle("")
	ylabel(100 "100" 50 "50" 0 "0" -50 "-50" -100 "-100" -150 "-150" -200 "-200" -250 "-250" -300 "-300" -350 "-350" -400 "-400" -450 "-450" -500 "-500" 	 -550 "-550") 
	xlabel(1990 "1990" 1992 "92" 1994 "94" 1996 "96" 1998 "98" 2000 "2000" 2002 "02" 2004 "04" 2006 "06" 2008 "08" 2010 "10" 2012 `""12" """' 2014 `""14" "Seleka occupation""' 2016 "16" 2018 "18") 
	xscale(range(1990 2018)) 
	text(-650 1996 ""); 
#delimit cr
graph export "./Output\Gap_GDPpc.png", as(png) replace


// ALL PLACEBO COUNTRIES

#delimit ;
twoway
	(tsline te1, lcolor(gs12) lwidth(vthin)) (tsline te2, lcolor(gs12) lwidth(vthin)) 
	(tsline te3, lcolor(gs12) lwidth(vthin))(tsline te4, lcolor(gs12) lwidth(vthin))
	(tsline te5, lcolor(gs12) lwidth(vthin)) (tsline te6, lcolor(gs12) lwidth(vthin))
	(tsline te7, lcolor(gs12) lwidth(vthin)) (tsline te8, lcolor(gs12) lwidth(vthin))
	(tsline te9, lcolor(gs12) lwidth(vthin)) (tsline te10, lcolor(gs12) lwidth(vthin))
	(tsline te11, lcolor(gs12) lwidth(vthin)) (tsline te12, lcolor(gs12) lwidth(vthin))
	(tsline te13, lcolor(gs12) lwidth(vthin)) (tsline te14, lcolor(gs12) lwidth(vthin))
	(tsline te15, lcolor(gs12) lwidth(vthin)) (tsline te16, lcolor(gs12) lwidth(vthin))
	(tsline te17, lcolor(gs12) lwidth(vthin)) (tsline te18, lcolor(gs12) lwidth(vthin))
	(tsline te19, lcolor(gs12) lwidth(vthin))
	(tsline car, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap GDPpc PPP (constant 2017 int. USD)")
	xtitle("Year")
	subtitle("We keep all placebo countries")
	/*ylabel(100 "100" 50 "50" 0 "0" -50 "-50" -100 "-100" -150 "-150" -200 "-200" -250 "-250" -300 "-300" -350 "-350" -400 "-400" -450 "-450" -500 "-500" 	 -550 "-550")*/
	xlabel(1990 "1990" 1992 "92" 1994 "94" 1996 "96" 1998 "98" 2000 "2000" 2002 "02" 2004 "04" 2006 "06" 2008 "08" 2010 "10" 2012 `""12" """' 2014 `""14" "Seleka occupation""' 2016 "16" 2018 "18") 
	xscale(range(1990 2018)) 
	text(-1500 1996 ""); 
#delimit cr
graph export "./Output\Placebo_GDPpc_All.png", as(png) replace


// EXCLUDING MSPE>= 5 times larger than CAR

#delimit ;
twoway
	/*(tsline te1, lcolor(gs12) lwidth(vthin))*/ (tsline te2, lcolor(gs12) lwidth(vthin)) 
	/*(tsline te3, lcolor(gs12) lwidth(vthin))*//*(tsline te4, lcolor(gs12) lwidth(vthin))*/
	(tsline te5, lcolor(gs12) lwidth(vthin)) /*(tsline te6, lcolor(gs12) lwidth(vthin))*/
	/*(tsline te7, lcolor(gs12) lwidth(vthin))*/ /*(tsline te8, lcolor(gs12) lwidth(vthin))*/
	(tsline te9, lcolor(gs12) lwidth(vthin)) (tsline te10, lcolor(gs12) lwidth(vthin))
	(tsline te11, lcolor(gs12) lwidth(vthin)) /*(tsline te12, lcolor(gs12) lwidth(vthin))*/
	(tsline te13, lcolor(gs12) lwidth(vthin)) /*(tsline te14, lcolor(gs12) lwidth(vthin))*/
	/*(tsline te15, lcolor(gs12) lwidth(vthin))*/ /*(tsline te16, lcolor(gs12) lwidth(vthin))*/
	/*(tsline te17, lcolor(gs12) lwidth(vthin))*/ /*(tsline te18, lcolor(gs12) lwidth(vthin))*/
	/*(tsline te19, lcolor(gs12) lwidth(vthin))*/ 
	(tsline car, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap GDPpc PPP (constant 2017 int. USD)")
	xtitle("Year")
	subtitle("No pre-GDPpc's MSPE five times higher than CAR's")
	/*ylabel(100 "100" 50 "50" 0 "0" -50 "-50" -100 "-100" -150 "-150" -200 "-200" -250 "-250" -300 "-300" -350 "-350" -400 "-400" -450 "-450" -500 "-500" 	 -550 "-550")*/
	xlabel(1990 "1990" 1992 "92" 1994 "94" 1996 "96" 1998 "98" 2000 "2000" 2002 "02" 2004 "04" 2006 "06" 2008 "08" 2010 "10" 2012 `""12" """' 2014 `""14" "Seleka occupation""' 2016 "16" 2018 "18") 
	xscale(range(1990 2018)) 
	text(-1500 1996 ""); 
#delimit cr
graph export "./Output\Placebo_GDPpc5.png", as(png) replace

}
}
