****************************************************************************

* || SCM LUMINOSITY INTENSITY || *

****************************************************************************
clear all
*
set memory 100m
set more off
import excel cap10km_dmsp_ext.xlsx, firstrow
drop if ISO==""
****************************************************************************
{
reshape long LIGHT, i(ISO) j(year)
order ISO CNTRY_NAME CITY_NAME year LIGHT
drop if LIGHT==.
rename CNTRY_NAME country
rename CITY_NAME capital_city
rename ISO iso3
rename LIGHT light
label var light "Light intensity in capital cities (10km areas, smoothed series)"

g light2012= light if year ==2012
bysort iso3: egen denominator= max(light2012)

g light_index= light/denominator*100 
label var light_index "Light intensity index=100 2012"
drop light2012 denominator

**
keep if year>=1992 & year<=2017 // 1992=> first year available for CAR; 2017=> N+5 since 2012 (year treatment)
bysort iso3: egen c_light = count(light_index) if light_index!=.

bysort iso3: sum c_light
keep if c_light==26
drop if iso3=="AFG" | iso3=="SYR" | iso3=="YEM" /*| iso3=="SSD" */  // Countries in war at the time of the treatment
sort country year
egen id= group(iso3)
list country id if year==2012 // CAR = ccode 3
order id iso3 country capital_city year light light_index

// SCM CAR: year of interest ==> 2012
{
/*
Potential donnor pool : All LIC countries except AFG, SYR, YEM (in war)
*/

xtset id year
g ln_light= ln(light)

*=> 2005-2017
*synth light light(1992) light(1993)  light(1994)  light(1995)  light(1996)  light(1997) light(1998) light(1999)  light(2000) light(2001) light(2002) light(2003) light(2004) light(2005) light(2006) light(2007) light(2008) light(2009) light(2010) light(2011), trunit(3) trperiod(2012)  figure keep(SCM1_LIC_LIGHT.dta, replace) // 2012 last year before war
**
preserve
keep if year>=2005 // Major reforms for ENERCA (national power utility company)

synth light light(2005) light(2007) light(2008) light(2009) light(2010) light(2011), trunit(3) trperiod(2012)  figure keep(SCM1_LIC_LIGHT_NOTADJUSTED.dta, replace) // 2012 last year before war

replace light= light + (4310.472-3592) if iso3=="CAF" & year>=2012  // LIGHT artificially readjusted [10km area]

synth light light(2005) light(2006) light(2007) light(2008) light(2009) light(2010) light(2011), trunit(3) trperiod(2012)  figure keep(SCM1_LIC_LIGHT.dta, replace) // 2012 last year before war

restore

}

// PLACEBO TEST
{

preserve
drop if id==3 // CAR
keep if year>=2005

global id  1 2 4 5 6 7 8 9 10 11 12 13 14 15 16 18 20 21 22 23 24 25
tempname resmat
tempname effect

foreach i of global id {
	synth light light(2005) light(2006) light(2007) light(2008) light(2009) light(2010) light(2011), trunit(`i') trperiod(2012) nested // nested option removed for (id=17) Sudan (id=19) Somalia
	matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
	matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
	local names `"`names' `"`i'"'"'
	
}


/*
*/
synth light light(2005) light(2006) light(2007) light(2008) light(2009) light(2010) light(2011), trunit(17) trperiod(2012) /*nested*/ // nested option removed for Sudan [lead to error in computation]
matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
local names `"`names' `"`17'"'"'

synth light light(2005) light(2006) light(2007) light(2008) light(2009) light(2010) light(2011), trunit(19) trperiod(2012) /*nested*/ // nested option removed for Sudan [lead to error in computation]
matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
local names `"`names' `"`19'"'"'


restore
keep if year>=2005
replace light= light + (4310.472-3592) if iso3=="CAF" & year>=2012 // LIGHT artificially readjusted [10km area]

synth light light(2005) light(2006) light(2007) light(2008) light(2009) light(2010) light(2011), trunit(3) trperiod(2012) nested figure /*counit(1 2 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25)*/ 
	matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
	matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
	local names `"`names' `"`3'"'"' 
	
mat colnames `resmat' = "RMSPE"
mat rownames `resmat' = `names'
mat colnames `effect' = "Treatment Effect"
matlist `resmat', row("Treated Unit")
matlist `effect', row("Year")
svmat `resmat', names(rmspe)
svmat `effect', names(te)


**
g mspe = rmspe1*rmspe1

scalar threshold5 = 8102.556* 5
tab mspe if mspe>threshold5 // to exclude: te1 te4 te5 te6 te11 te12 te14 te15 te17 te18 te20 te21 te22 te23 te24 
**

keep year te*
drop if te1==. // ``clean'' the database
rename te25 car // CAR effect 

*=> standardize to 0 for year 2012 (reference)
rename car te25
reshape long te, i(year) j(country)
sort country year
by country: gen v = te[8] // 2012 is the 8th year
replace te = te - v
drop v
reshape wide te, i(year) j(country)
rename te25 car  // CAR effect 

// CAR ALONE

#delimit ;
twoway
	(tsline car, lcolor(black) lwidth(medthick)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap nighttime light intensity")
	xtitle("Year")
	subtitle("")
	/*ylabel(100 "100" 50 "50" 0 "0" -50 "-50" -100 "-100" -150 "-150" -200 "-200" -250 "-250" -300 "-300" -350 "-350" -400 "-400" -450 "-450" -500 "-500" 	 -550 "-550")*/
	xlabel(2005 "2005" 2006 "06" 2007 "07" 2008 "08" 2009 "09" 2010 "10" 2011 "11" 2012 `""12" """' 2013 `""13" "Seleka occupation""' 2014 `""14" """' 2015 "15" 2016 "16" 2017 "17" 2018 "18") 
	xscale(range(2005 2018)) 
	text(-650 1996 ""); 
#delimit cr
graph export "./Output\Gap_Light.png", as(png) replace


// ALL PLACEBO COUNTRIES

#delimit ;
twoway
	(tsline te1, lcolor(gs12) lwidth(vthin)) (tsline te2, lcolor(gs12) lwidth(vthin)) 
	(tsline te3, lcolor(gs12) lwidth(vthin))(tsline te4, lcolor(gs12) lwidth(vthin))
	(tsline te5, lcolor(gs12) lwidth(vthin)) (tsline te6, lcolor(gs12) lwidth(vthin))
	(tsline te7, lcolor(gs12) lwidth(vthin)) (tsline te8, lcolor(gs12) lwidth(vthin))
	(tsline te9, lcolor(gs12) lwidth(vthin)) (tsline te10, lcolor(gs12) lwidth(vthin))
	(tsline te11, lcolor(gs12) lwidth(vthin)) (tsline te12, lcolor(gs12) lwidth(vthin))
	(tsline te13, lcolor(gs12) lwidth(vthin)) (tsline te14, lcolor(gs12) lwidth(vthin))
	(tsline te15, lcolor(gs12) lwidth(vthin)) (tsline te16, lcolor(gs12) lwidth(vthin))
	(tsline te17, lcolor(gs12) lwidth(vthin)) (tsline te18, lcolor(gs12) lwidth(vthin))
	(tsline te19, lcolor(gs12) lwidth(vthin)) (tsline te20, lcolor(gs12) lwidth(vthin))
	(tsline te21, lcolor(gs12) lwidth(vthin)) (tsline te22, lcolor(gs12) lwidth(vthin))
	(tsline te23, lcolor(gs12) lwidth(vthin)) (tsline te24, lcolor(gs12) lwidth(vthin))
	(tsline car, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Nighttime light intensity")
	xtitle("Year")
	subtitle("We keep all placebo countries")
	/*ylabel(100 "100" 50 "50" 0 "0" -50 "-50" -100 "-100" -150 "-150" -200 "-200" -250 "-250" -300 "-300" -350 "-350" -400 "-400" -450 "-450" -500 "-500" 	 -550 "-550")*/
	xlabel(2005 "2005" 2006 "06" 2007 "07" 2008 "08" 2009 "09" 2010 "10" 2011 "11" 2012 `""12" """' 2013 `""13" "Seleka occupation""' 2014 `""14" """' 2015 "15" 2016 "16" 2017 "17" 2018 "18") 
	xscale(range(2005 2018))
	text(-1500 1996 ""); 
#delimit cr
graph export "./Output\Placebo_Light_All.png", as(png) replace


// EXCLUDING MSPE>= 5 times larger than CAR

#delimit ;
twoway
	/*(tsline te1, lcolor(gs12) lwidth(vthin))*/ (tsline te2, lcolor(gs12) lwidth(vthin)) 
	(tsline te3, lcolor(gs12) lwidth(vthin)) /*(tsline te4, lcolor(gs12) lwidth(vthin))*/
	/*(tsline te5, lcolor(gs12) lwidth(vthin))*/ /*(tsline te6, lcolor(gs12) lwidth(vthin))*/
	(tsline te7, lcolor(gs12) lwidth(vthin)) (tsline te8, lcolor(gs12) lwidth(vthin))
	(tsline te9, lcolor(gs12) lwidth(vthin)) (tsline te10, lcolor(gs12) lwidth(vthin))
	/*(tsline te11, lcolor(gs12) lwidth(vthin))*/ /*(tsline te12, lcolor(gs12) lwidth(vthin))*/
	(tsline te13, lcolor(gs12) lwidth(vthin)) /*(tsline te14, lcolor(gs12) lwidth(vthin))*/
	/*(tsline te15, lcolor(gs12) lwidth(vthin))*/ (tsline te16, lcolor(gs12) lwidth(vthin))
	/*(tsline te17, lcolor(gs12) lwidth(vthin))*/ /*(tsline te18, lcolor(gs12) lwidth(vthin))*/
	(tsline te19, lcolor(gs12) lwidth(vthin)) /*(tsline te20, lcolor(gs12) lwidth(vthin))*/
	/*(tsline te21, lcolor(gs12) lwidth(vthin))*/ /*(tsline te22, lcolor(gs12) lwidth(vthin))*/
	/*(tsline te23, lcolor(gs12) lwidth(vthin))*/ /*(tsline te24, lcolor(gs12) lwidth(vthin))*/
	(tsline car, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Nighttime light intensity")
	xtitle("Year")
	subtitle("No pre-NTL's MSPE five times higher than CAR's")
	/*ylabel(100 "100" 50 "50" 0 "0" -50 "-50" -100 "-100" -150 "-150" -200 "-200" -250 "-250" -300 "-300" -350 "-350" -400 "-400" -450 "-450" -500 "-500" 	 -550 "-550")*/
	xlabel(2005 "2005" 2006 "06" 2007 "07" 2008 "08" 2009 "09" 2010 "10" 2011 "11" 2012 `""12" """' 2013 `""13" "Seleka occupation""' 2014 `""14" """' 2015 "15" 2016 "16" 2017 "17" 2018 "18") 
	xscale(range(2005 2018))
	text(-1500 1996 ""); 
#delimit cr
graph export "./Output\Placebo_Light5.png", as(png) replace

}
}
