* || SCM INDUSTRIAL (INCL. CONSTRUCTION) ACTIVITY || *

****************************************************************************
clear all
*
set memory 100m
set more off
import excel Data_WDI_panel-version_LICsample_Industry.xlsx, firstrow
****************************************************************************
{
drop if CountryCode==""
rename CountryCode iso3
rename CountryName country
rename Time year

foreach x in Industryincludingconstruction {
replace `x'="" if `x'==".."
destring `x', replace
}
**

g indu2012= Industryincludingconstruction if year ==2012
bysort iso3: egen denominator= max(indu2012)

g industry= Industryincludingconstruction/denominator*100 
label var industry "Industry value added index=100 2012"
drop indu2012 denominator



**
keep if year>=2009 & year<=2017 // 2009=> first year available for CAR; 2017=> N+5 since 2012 (year treatment)
bysort iso3: egen c_industry = count(industry) if industry!=.

bysort iso3: sum c_industry
keep if c_industry==9
drop if iso3=="AFG" | iso3=="SYR" | iso3=="YEM" // Countries in war at the time of the treatment
sort country year
egen id= group(iso3)
list country id if year==2012 // CAR = ccode 3
order id iso3 country year TimeCode industry


// SCM CAR: year of interest ==> 2012
{
/*
Potential donnor pool : BFA, BDI, TCD, COD, ETH, GMB, GIN, GNB, MDG, MWI, MLI, MOZ, NER, RWA, SLE, SDN, TGO, UGA
*/
xtset id year

*=> 2009-2017

synth industry industry(2009) industry(2010) industry(2011), trunit(3) trperiod(2012)  figure keep(SCM1_LIC_INDUSTRY.dta, replace) // 2012 last year before war
}


// PLACEBO TEST
{

preserve
drop if id==3 // CAR
global id  1 2 4 5 6 7 8 10 11 12 13 14 15 17 18 19 20 21
tempname resmat
tempname effect

foreach i of global id {
	synth industry industry(2009) industry(2010) industry(2011), trunit(`i') trperiod(2012) nested // nested option removed for (id=9) Liberia and (id=16) Sudan
	matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
	matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
	local names `"`names' `"`i'"'"'
	
}

/*
*/
synth industry industry(2009) industry(2010) industry(2011), trunit(9) trperiod(2012) /*nested*/ // nested option removed for Liberia [lead to error in computation]
matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
local names `"`names' `"`9'"'"'

synth industry industry(2009) industry(2010) industry(2011), trunit(9) trperiod(2012) /*nested*/ // nested option removed for Sudan [lead to error in computation]
matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
local names `"`names' `"`16'"'"'

restore

synth industry industry(2009) industry(2010) industry(2011), trunit(3) trperiod(2012) nested /*counit(1 2 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21)*/ 
	matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
	matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
	local names `"`names' `"`2'"'"' 
	
mat colnames `resmat' = "RMSPE"
mat rownames `resmat' = `names'
mat colnames `effect' = "Treatment Effect"
matlist `resmat', row("Treated Unit")
matlist `effect', row("Year")
svmat `resmat', names(rmspe)
svmat `effect', names(te)


**
g mspe = rmspe1*rmspe1

scalar threshold5 = 4.71E-22* 5
tab mspe if mspe>threshold5 // to exclude: [...]
**

keep year te*
drop if te1==. // ``clean'' the databse
rename te21 car // CAR effect 

*=> standardize to 0 for year 2012 (reference)

rename car te21
reshape long te, i(year) j(country)
sort country year
by country: gen v = te[4] // 2012 is the 4th year 
replace te = te - v
drop v
reshape wide te, i(year) j(country)
rename te21 car  // CAR effect 


// CAR ALONE

#delimit ;
twoway
	(tsline car, lcolor(black) lwidth(medthick)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Industry value added (index 100 =2012)")
	xtitle("Year")
	subtitle("")
	ylabel(20 "20" 10 "10" 0 "0" -10 "-10" -20 "-20" -30 "-30" -40 "-40" -50 "-50") 
	xlabel(2009 "2009" 2010 "10" 2011 "11" 2012 `""12" """' 2013 `""13" "Seleka occupation""' 2014 `""14" """' 2015 "15" 2016 "16" 2017 "17") 
	xscale(range(2009 2017)) 
	text(-65 2010 ""); 
#delimit cr
graph export "./Output\Gap_Industry.png", as(png) replace


// ALL PLACEBO COUNTRIES

#delimit ;
twoway
	(tsline te1, lcolor(gs12) lwidth(vthin)) 
	(tsline te2, lcolor(gs12) lwidth(vthin))
	(tsline te3, lcolor(gs12) lwidth(vthin)) 
	(tsline te4, lcolor(gs12) lwidth(vthin)) 
	(tsline te5, lcolor(gs12) lwidth(vthin)) 
	(tsline te6, lcolor(gs12) lwidth(vthin)) 
	(tsline te7, lcolor(gs12) lwidth(vthin)) 
	(tsline te8, lcolor(gs12) lwidth(vthin)) 
	(tsline te9, lcolor(gs12) lwidth(vthin)) 
	(tsline te10, lcolor(gs12) lwidth(vthin)) 
	(tsline te11, lcolor(gs12) lwidth(vthin)) 
	(tsline te12, lcolor(gs12) lwidth(vthin)) 
	(tsline te13, lcolor(gs12) lwidth(vthin)) 
	(tsline te14, lcolor(gs12) lwidth(vthin)) 
	(tsline te15, lcolor(gs12) lwidth(vthin)) 
	(tsline te16, lcolor(gs12) lwidth(vthin))
	(tsline te17, lcolor(gs12) lwidth(vthin)) 
	(tsline te18, lcolor(gs12) lwidth(vthin)) 
	(tsline te19, lcolor(gs12) lwidth(vthin)) 
	(tsline te20, lcolor(gs12) lwidth(vthin)) 
	(tsline car, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Industry value added (index 100 =2012)")
	xtitle("Year")
	subtitle("We keep all placebo countries")
	xlabel(2009 "2009" 2010 "10" 2011 "11" 2012 `""12" """' 2013 `""13" "Seleka occupation""' 2014 `""14" """' 2015 "15" 2016 "16" 2017 "17") 
	xscale(range(2009 2017)) 
	text(-98 2012 "");
#delimit cr
graph export "./Output\Placebo_Industry_All.png", as(png) replace


// EXCLUDING MSPE>= 5 times larger than CAR

#delimit ;
twoway
	(tsline te4, lcolor(gs12) lwidth(vthin)) 
	(tsline te11, lcolor(gs12) lwidth(vthin)) 
	(tsline te13, lcolor(gs12) lwidth(vthin)) 
	(tsline te17, lcolor(gs12) lwidth(vthin)) 
	(tsline car, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Industry value added (index 100 =2012)")
	xtitle("Year")
	subtitle("No pre-Industrial's MSPE five times higher than CAR's")
	xlabel(2009 "2009" 2010 "10" 2011 "11" 2012 `""12" """' 2013 `""13" "Seleka occupation""' 2014 `""14" """' 2015 "15" 2016 "16" 2017 "17") 
	xscale(range(2009 2017)) 
	text(-98 2012 "");
#delimit cr
graph export "./Output\Placebo_Industry5.png", as(png) replace

}
}
