* || SCM MANUFACTURING ACTIVITY || *

****************************************************************************
clear all
*
set memory 100m
set more off
import excel Data_WDI_panel_version_LICsample_Manuf.xlsx, firstrow
****************************************************************************
{
drop if CountryCode==""
rename CountryCode iso3
rename CountryName country
rename Time year

foreach x in Manufacturingvalueaddedof {
replace `x'="" if `x'==".."
destring `x', replace
}
**

g manuf2012= Manufacturingvalueaddedof if year ==2012
bysort iso3: egen denominator= max(manuf2012)

g manuf= Manufacturingvalueaddedof/denominator*100 
label var manuf "Manfacturing value added index=100 2012"
drop manuf2012 denominator



**
keep if year>=2009 & year<=2017 // 2009=> first year available for CAR; 2017=> N+5 since 2012 (year treatment)
bysort iso3: egen c_manuf = count(manuf) if manuf!=.

bysort iso3: sum c_manuf
keep if c_manuf==9
drop if iso3=="AFG" // Country in war at the time of the treatment
sort country year
egen id= group(iso3)
list country id if year==2012 // CAR = ccode 2
order id iso3 country year TimeCode manuf



// SCM CAR: year of interest ==> 2012
{
/*
Potential donnor pool : BFA, TCD, COD, ETH, GMB, GIN, GNB, MDG, MWI, MOZ, NER, RWA, SLE, TGO, UGA, ZMB
*/
xtset id year

*=> 2009-2017

synth manuf manuf(2009) manuf(2010) manuf(2011), trunit(2) trperiod(2012)  figure keep(SCM1_LIC_MANUF.dta, replace) // 2012 last year before war
}


// PLACEBO TEST
{

preserve
drop if id==2 // CAR
global id  1 3 4 5 6 7 8 9 10 11 12 13 14 16 17 18
tempname resmat
tempname effect

foreach i of global id {
	synth manuf manuf(2009) manuf(2010) manuf(2011), trunit(`i') trperiod(2012) nested // nested option removed for (id=15) Chad
	matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
	matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
	local names `"`names' `"`i'"'"'
	
}
/*
*/
synth manuf manuf(2009) manuf(2010) manuf(2011), trunit(15) trperiod(2012) /*nested*/ // nested option removed for Chad [lead to error in computation]
matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
local names `"`names' `"`9'"'"'

restore

synth manuf manuf(2009) manuf(2010) manuf(2011), trunit(2) trperiod(2012) nested counit(1 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18) 
	matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
	matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
	local names `"`names' `"`2'"'"' 
	
mat colnames `resmat' = "RMSPE"
mat rownames `resmat' = `names'
mat colnames `effect' = "Treatment Effect"
matlist `resmat', row("Treated Unit")
matlist `effect', row("Year")
svmat `resmat', names(rmspe)
svmat `effect', names(te)


**
g mspe = rmspe1*rmspe1

scalar threshold5 = 2.772224* 5
tab mspe if mspe>threshold5 // to exclude: te1 te17 
**


keep year te*
drop if te1==. // ``clean'' the database
rename te18 car // CAR effect 

*=> standardize to 0 for year 2012 (reference)

rename car te18
reshape long te, i(year) j(country)
sort country year
by country: gen v = te[4] // 2012 is the 4th year
replace te = te - v
drop v
reshape wide te, i(year) j(country)
rename te18 car  // CAR effect 


// CAR ALONE

#delimit ;
twoway
	(tsline car, lcolor(black) lwidth(medthick)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Manufacturing value added (index 100 =2012)")
	xtitle("Year")
	subtitle("")
	ylabel(20 "20" 10 "10" 0 "0" -10 "-10" -20 "-20" -30 "-30" -40 "-40" -50 "-50") 
	xlabel(2009 "2009" 2010 "10" 2011 "11" 2012 `""12" """' 2013 `""13" "Seleka occupation""' 2014 `""14" """' 2015 "15" 2016 "16" 2017 "17") 
	xscale(range(2009 2017)) 
	text(-65 2010 ""); 
#delimit cr
graph export "./Output\Gap_Manuf.png", as(png) replace




// ALL PLACEBO COUNTRIES

#delimit ;
twoway
	(tsline te1, lcolor(gs12) lwidth(vthin)) 
	(tsline te2, lcolor(gs12) lwidth(vthin))
	(tsline te3, lcolor(gs12) lwidth(vthin)) 
	(tsline te4, lcolor(gs12) lwidth(vthin)) 
	(tsline te5, lcolor(gs12) lwidth(vthin)) 
	(tsline te6, lcolor(gs12) lwidth(vthin)) 
	(tsline te7, lcolor(gs12) lwidth(vthin)) 
	(tsline te8, lcolor(gs12) lwidth(vthin)) 
	(tsline te9, lcolor(gs12) lwidth(vthin)) 
	(tsline te10, lcolor(gs12) lwidth(vthin)) 
	(tsline te11, lcolor(gs12) lwidth(vthin)) 
	(tsline te12, lcolor(gs12) lwidth(vthin)) 
	(tsline te13, lcolor(gs12) lwidth(vthin)) 
	(tsline te14, lcolor(gs12) lwidth(vthin)) 
	(tsline te15, lcolor(gs12) lwidth(vthin)) 
	(tsline te16, lcolor(gs12) lwidth(vthin))
	(tsline te17, lcolor(gs12) lwidth(vthin)) 
	(tsline car, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Manufacturing value added (index 100 =2012)")
	xtitle("Year")
	subtitle("We keep all placebo countries")
	xlabel(2009 "2009" 2010 "10" 2011 "11" 2012 `""12" """' 2013 `""13" "Seleka occupation""' 2014 `""14" """' 2015 "15" 2016 "16" 2017 "17") 
	xscale(range(2009 2017)) 
	text(-98 2012 "");
#delimit cr
graph export "./Output\Placebo_Manuf_All.png", as(png) replace


// EXCLUDING MSPE>= 5 times larger than CAR

#delimit ;
twoway
	/*(tsline te1, lcolor(gs12) lwidth(vthin))*/ 
	(tsline te2, lcolor(gs12) lwidth(vthin))
	(tsline te3, lcolor(gs12) lwidth(vthin)) 
	(tsline te4, lcolor(gs12) lwidth(vthin)) 
	(tsline te5, lcolor(gs12) lwidth(vthin)) 
	(tsline te6, lcolor(gs12) lwidth(vthin)) 
	(tsline te7, lcolor(gs12) lwidth(vthin)) 
	(tsline te8, lcolor(gs12) lwidth(vthin)) 
	(tsline te9, lcolor(gs12) lwidth(vthin)) 
	(tsline te10, lcolor(gs12) lwidth(vthin)) 
	(tsline te11, lcolor(gs12) lwidth(vthin)) 
	(tsline te12, lcolor(gs12) lwidth(vthin)) 
	(tsline te13, lcolor(gs12) lwidth(vthin)) 
	(tsline te14, lcolor(gs12) lwidth(vthin)) 
	(tsline te15, lcolor(gs12) lwidth(vthin)) 
	(tsline te16, lcolor(gs12) lwidth(vthin))
	/*(tsline te17, lcolor(gs12) lwidth(vthin))*/ 
	(tsline car, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Manufacturing value added (index 100 =2012)")
	xtitle("Year")
	subtitle("No pre-Manufacturing's MSPE five times higher than CAR's")
	xlabel(2009 "2009" 2010 "10" 2011 "11" 2012 `""12" """' 2013 `""13" "Seleka occupation""' 2014 `""14" """' 2015 "15" 2016 "16" 2017 "17") 
	xscale(range(2009 2017)) 
	text(-90 2012 "");
#delimit cr
graph export "./Output\Placebo_Manuf5.png", as(png) replace


}
}
