* || SCM HUMAN CAPITAL || *

****************************************************************************
clear all
*
set memory 100m
set more off
import excel data-series-retrospectives-de-l-indice-hai.xlsx, firstrow sheet(HAI2_noLR)
****************************************************************************
{
reshape long HAI, i(iso_3) j(year)
rename iso_3 iso3
keep if iso3=="AFG" | iso3=="BDI" | iso3=="BFA" | iso3=="CAF" | iso3=="COD" | iso3=="ERI" | ///
iso3=="ETH" | iso3=="GIN" | iso3=="GMB" | iso3=="GNB" | iso3=="LBR" | iso3=="MDG" | ///
iso3=="MLI" | iso3=="MOZ" | iso3=="MWI" | iso3=="NER" | iso3=="PRK" | iso3=="RWA" | ///
iso3=="SDN" | iso3=="SLE" | iso3=="SOM" | iso3=="SSD" | iso3=="SYR" | iso3=="TCD" | ///
iso3=="TGO" | iso3=="UGA" | iso3=="YEM" | iso3=="ZMB"



g hai2012= HAI if year ==2012
bysort iso3: egen denominator= max(hai2012)

g hai_index= HAI/denominator*100 
label var hai_index "Human asset index index=100 2012"
drop hai2012 denominator

rename HAI hai
label var hai "Reduced Human asset index (no adult literacy rate), from FERDI database"


**
keep if year>=1990 & year<=2017 // 1990=> first year available for CAR; 2017=> N+5 since 2012 (year treatment)
bysort iso3: egen c_hai = count(hai_index) if hai_index!=.

bysort iso3: sum c_hai
keep if c_hai==25
drop if iso3=="AFG" | iso3=="SYR" // Country in war at the time of the treatment
sort country year
egen id= group(iso3)
list country id if year==2012 // CAR = ccode 3
order id iso3 country year hai


// SCM CAR: year of interest ==> 2012
{
/*
Potential donnor pool : BFA, BDI, TCD, COD, ERI, ETH, GMB, GIN, GNB, LBR, MDG, MWI, MLI, MOZ, NER, RWA, SLE, SOM, SDN, TGO, UGA, YEM, ZMB
*/
xtset id year

*=> 1990-2017

synth hai hai(1990) hai(1991) hai(1992) hai(1993)  hai(1994)  hai(1995)  hai(1996)  hai(1997) hai(1998) hai(1999)  hai(2000) hai(2001) hai(2002) hai(2003) hai(2004) hai(2005) hai(2006) hai(2007) hai(2008) hai(2009) hai(2010) hai(2011), trunit(3) trperiod(2012)  figure keep(SCM1_LIC_HAI_NOTADJUSTED.dta, replace) // 2012 last year before war

preserve
replace hai= hai + (26.815517-23.601282) if iso3=="CAF" & year>=2012 // HAI artificially readjusted

synth hai hai(1990) hai(1991) hai(1992) hai(1993)  hai(1994)  hai(1995)  hai(1996)  hai(1997) hai(1998) hai(1999)  hai(2000) hai(2001) hai(2002) hai(2003) hai(2004) hai(2005) hai(2006) hai(2007) hai(2008) hai(2009) hai(2010) hai(2011), trunit(3) trperiod(2012)  figure keep(SCM1_LIC_HAI.dta, replace) // 2012 last year before war

restore

}



// PLACEBO TEST
{

replace hai= hai + (26.815517-23.601282) if iso3=="CAF" & year>=2012 // HAI artificially readjusted
preserve
drop if id==3 // CAR
global id  2 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 
tempname resmat
tempname effect

foreach i of global id {
	synth hai hai(1990) hai(1991) hai(1992) hai(1993)  hai(1994)  hai(1995)  hai(1996)  hai(1997) hai(1998) hai(1999)  hai(2000) hai(2001) hai(2002) hai(2003) hai(2004) hai(2005) hai(2006) hai(2007) hai(2008) hai(2009) hai(2010) hai(2011), trunit(`i') trperiod(2012) nested // nested option removed for (id=1) Burundi
	matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
	matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
	local names `"`names' `"`i'"'"'
	
}

synth hai hai(1990) hai(1991) hai(1992) hai(1993)  hai(1994)  hai(1995)  hai(1996)  hai(1997) hai(1998) hai(1999)  hai(2000) hai(2001) hai(2002) hai(2003) hai(2004) hai(2005) hai(2006) hai(2007) hai(2008) hai(2009) hai(2010) hai(2011), trunit(1) trperiod(2012) /*nested*/ // nested option removed for Burundi [lead to error in computation]
matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
local names `"`names' `"`1'"'"'

restore

synth hai hai(1990) hai(1991) hai(1992) hai(1993)  hai(1994)  hai(1995)  hai(1996)  hai(1997) hai(1998) hai(1999)  hai(2000) hai(2001) hai(2002) hai(2003) hai(2004) hai(2005) hai(2006) hai(2007) hai(2008) hai(2009) hai(2010) hai(2011), trunit(3) trperiod(2012) nested figure /*counit(1 2 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24)*/ 
	matrix `resmat' = nullmat(`resmat') \ e(RMSPE)
	matrix `effect' = nullmat(`effect'), (e(Y_treated)-e(Y_synthetic)) 
	local names `"`names' `"`3'"'"' 
	
mat colnames `resmat' = "RMSPE"
mat rownames `resmat' = `names'
mat colnames `effect' = "Treatment Effect"
matlist `resmat', row("Treated Unit")
matlist `effect', row("Year")
svmat `resmat', names(rmspe)
svmat `effect', names(te)


/*
*/



**
g mspe = rmspe1*rmspe1

scalar threshold5 = 2.488547* 5
tab mspe if mspe>threshold5 // to exclude: te1 te3 te4 te6 te8 te11 te12 te14 te15 te16 te17 te18 te21 te22 te23
**

keep year te*
drop if te1==. // ``nettoyer'' la base
rename te24 car // CAR effect 

*=> standardiser a 0 pour l'annee 2012 (reference)

rename car te24
reshape long te, i(year) j(country)
sort country year
by country: gen v = te[23] // 2012 est la 23eme annee 
replace te = te - v
drop v
reshape wide te, i(year) j(country)
rename te24 car  // CAR effect 


// CAR ALONE

#delimit ;
twoway
	(tsline car, lcolor(black) lwidth(medthick)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Reduced Human Asset Index")
	xtitle("Year")
	subtitle("")
	ylabel(10 "10" 5 "5" 0 "0" -5 "-5" -10 "-10") 
	xlabel(1990 "1990" 1992 "92" 1994 "94" 1996 "96" 1998 "98" 2000 "2000" 2002 "02" 2004 "04" 2006 "06" 2008 "08" 2010 "10" 2012 `""12" "Seleka Occupation""' 2014 `""14" """') 
	xscale(range(1990 2014)) 
	text(-25 1994 ""); 
#delimit cr
graph export "./Output\Gap_HAI.png", as(png) replace



// ALL PLACEBO COUNTRIES

#delimit ;
twoway
	(tsline te1, lcolor(gs12) lwidth(vthin)) 
	(tsline te2, lcolor(gs12) lwidth(vthin))
	(tsline te3, lcolor(gs12) lwidth(vthin)) 
	(tsline te4, lcolor(gs12) lwidth(vthin)) 
	(tsline te5, lcolor(gs12) lwidth(vthin)) 
	(tsline te6, lcolor(gs12) lwidth(vthin)) 
	(tsline te7, lcolor(gs12) lwidth(vthin)) 
	(tsline te8, lcolor(gs12) lwidth(vthin)) 
	(tsline te9, lcolor(gs12) lwidth(vthin)) 
	(tsline te10, lcolor(gs12) lwidth(vthin)) 
	(tsline te11, lcolor(gs12) lwidth(vthin)) 
	(tsline te12, lcolor(gs12) lwidth(vthin)) 
	(tsline te13, lcolor(gs12) lwidth(vthin)) 
	(tsline te14, lcolor(gs12) lwidth(vthin)) 
	(tsline te15, lcolor(gs12) lwidth(vthin)) 
	(tsline te16, lcolor(gs12) lwidth(vthin))
	(tsline te17, lcolor(gs12) lwidth(vthin)) 
	(tsline te18, lcolor(gs12) lwidth(vthin)) 
	(tsline te19, lcolor(gs12) lwidth(vthin)) 
	(tsline te20, lcolor(gs12) lwidth(vthin)) 
	(tsline te21, lcolor(gs12) lwidth(vthin)) 
	(tsline te22, lcolor(gs12) lwidth(vthin)) 
	(tsline te23, lcolor(gs12) lwidth(vthin)) 
	(tsline car, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Reduced human asset index")
	xtitle("Year")
	subtitle("We keep all placebo countries")
	ylabel(20 "20" 15 "15" 10 "10" 5 "5" 0 "0" -5 "-5" -10 "-10" -15 "-15" -20 "-20") 
	xlabel(1990 "1990" 1992 "92" 1994 "94" 1996 "96" 1998 "98" 2000 "2000" 2002 "02" 2004 "04" 2006 "06" 2008 "08" 2010 "10" 2012 `""12" "Seleka Occupation""' 2014 `""14" """') 
	xscale(range(1990 2014)) 
	text(-25 1994 ""); 
#delimit cr
graph export "./Output\Placebo_HAI_All.png", as(png) replace



// EXCLUDING MSPE>= 5 times larger than CAR

#delimit ;
twoway
	/*(tsline te1, lcolor(gs12) lwidth(vthin))*/ 
	(tsline te2, lcolor(gs12) lwidth(vthin))
	/*(tsline te3, lcolor(gs12) lwidth(vthin))*/ 
	/*(tsline te4, lcolor(gs12) lwidth(vthin))*/ 
	(tsline te5, lcolor(gs12) lwidth(vthin)) 
	/*(tsline te6, lcolor(gs12) lwidth(vthin))*/ 
	(tsline te7, lcolor(gs12) lwidth(vthin)) 
	/*(tsline te8, lcolor(gs12) lwidth(vthin))*/ 
	(tsline te9, lcolor(gs12) lwidth(vthin)) 
	(tsline te10, lcolor(gs12) lwidth(vthin)) 
	/*(tsline te11, lcolor(gs12) lwidth(vthin))*/ 
	/*(tsline te12, lcolor(gs12) lwidth(vthin))*/ 
	(tsline te13, lcolor(gs12) lwidth(vthin)) 
	/*(tsline te14, lcolor(gs12) lwidth(vthin))*/ 
	/*(tsline te15, lcolor(gs12) lwidth(vthin))*/ 
	/*(tsline te16, lcolor(gs12) lwidth(vthin))*/ 
	/*(tsline te17, lcolor(gs12) lwidth(vthin))*/ 
	/*(tsline te18, lcolor(gs12) lwidth(vthin))*/ 
	(tsline te19, lcolor(gs12) lwidth(vthin))
	(tsline te20, lcolor(gs12) lwidth(vthin))
	/*(tsline te21, lcolor(gs12) lwidth(vthin))*/ 
	/*(tsline te22, lcolor(gs12) lwidth(vthin))*/ 
	/*(tsline te23, lcolor(gs12) lwidth(vthin))*/ 
	(tsline car, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
	xline(2012 2014, lcolor(red) lpattern(dash))
	yline(0, lcolor(black))
	legend(off)
	ytitle("Gap Reduced human asset index")
	xtitle("Year")
	subtitle("No pre-HAI's MSPE five times higher than CAR's")
	ylabel(10 "10" 5 "5" 0 "0" -5 "-5" -10 "-10") 
	xlabel(1990 "1990" 1992 "92" 1994 "94" 1996 "96" 1998 "98" 2000 "2000" 2002 "02" 2004 "04" 2006 "06" 2008 "08" 2010 "10" 2012 `""12" "Seleka Occupation""' 2014 `""14" """') 
	xscale(range(1990 2014)) 
	text(-25 1994 ""); 
#delimit cr
graph export "./Output\Placebo_HAI5.png", as(png) replace

}

}


* || TABLE A1 || *

/*

Table A1 is built on the respective weights for each SCM and on pre-post event adjustments
* Run the SCM do file for the weights and for the MSPE of each specification
* Run the SCM do file for the pre and post war values of output for CAR and Synthetic of each specification or check directly the "Des stat and SCM.xlsx" file in "Output" folder

*/


*\END HERE